function [E_sub,E_sup,rhosub_crs,Vsub_crs,Msub,Msup,CL_sub, CL_sup,CD_sub,CD_sup,CD0_sub,CD0_sup,GainFactor,TA_OE,AR,e,d_int,d_ext,eff,c_SRM,...
    alfasub,alfasup,eta,sweep_w_d,sweep_w_r,l_ac,cr_w,b,cr_t,h_t,l_n,d_n,musub_crs,k,perc_l_f_sub,perc_l_w_sub,perc_l_t_sub,perc_l_n_sub,...
    p_f_sub,p_w_sub, p_t_sub,p_n_sub,p_f_sup,p_w_sup,p_t_sup,p_n_sup,x_c,t_c,p_md_sub,p_lp_sub,p_md_sup,p_lp_sup,S_c,Ewd,Q_w,Q_f,Q_t,Q_n] = Aerodynamics(NT,WS,...
    fl3,fl4)
% DESCRIPTION: AERODYNAMICS COEFFICIENTS ESTIMATION ,BUILD UP METHOD

%INPUT: NET THRUST, WING SURFACE [NT,WS] (Statistcial analysis)
%       ALTITUDE [fl3,fl4] (Mission profile)
%OUTPUT: E_sub, E_sup -->Fuel Weight
%        Vsub_crs (subsonic cruise speed)-->Fuel Weigth,TW_RequirementVerification
%        Msup (Supersonic cruise Mach) --> Fuel Weight, Tank_Layer_Sizing.m
%        Msub (Subsonic cruise Mach) --> Fuel Weigth
%        CL_sub, CL_sup (lift coefficient sub and
%        supersonic)-->WS_RequirementVerification
%        rhosub_crs (density subsonic cruise) -->TW_RquirementVerification
%        CD0_sub (parasite drag subsonic cruise) -->TW_RquirementVerification
%        CD0_sup (parasite drag supersonic cruise) -->TW_RquirementVerification
%        GainFactor (number engines) -->TW_RquirementVerification
%        TA_OE (thrust for one engine) -->TW_RquirementVerification
%        d_int,d_ext (Internal and External Fuselage Diameter)-->Tank_Layer_Sizing.m
%
%        FROM eff TO Ewd --> Aerodynamics_Loop.m


%% INPUT SECTION
disp(' ')
disp(' INPUT SECTION: ')

disp(' ')
disp('--> CHARACTERISTIC PARAMETERS OF REGIMES <--')

disp(' ')
disp('Insert a Mach number for SUBSONIC and SUPERSONIC regime:')
Msub=input('SUBSONIC Mach number: ');
Msup=input('SUPERSONIC Mach number: ');

disp(' ')
disp('Insert a value of Incidence Angle (alfa) to estimate CL in SUBSONIC and SUPERSONIC regime[°]:')
alfasub=input('SUBSONIC regime: ');
alfasub=alfasub*pi/180;
alfasup=input('SUPERSONIC regime: ');
alfasup=alfasup*pi/180;
disp(' ')
disp('--> WING <--')

disp(' ')
disp('Aifoil aerodynamic efficiency:')
disp('If the airfoil lift-curve slope as function on Mach is unknowed the costant value 0.95 is assumed')
disp('Do you want insert a value?')
disp('1. YES  2.NO')
etac=input('');

if etac==1
    disp(' ')
    disp('Insert a value of Aifoil aerodynamic efficiency')
    eta=input('');
end

if etac==2
    eta=0.95; %Raymer reference (airfoil lift-curve slope as function on Mach unknowed)
end

disp(' ')
disp('Wing Sweep Angle [deg]:')
sweep_w_d=55; %[°] Reference Concorde
%sweep_w_d=input('');
sweep_w_r=pi*sweep_w_d/180; %[rad]

disp(' ')
disp('Wing span [m]:')
b=25;  %[m] wing span; Corcorde Reference. %18 Reference document for Overture
%b=input('');

disp(' ')
disp('Wing Root chord  [m]:')
cr_w=27; %[m] Wing root chord, Concorde
%cr_w=input('');

disp(' ')
disp('Percentage Wing Wetted Area :')            
%p=input('SUBSONIC REGIME: ');  %[%] percentage of wetted wing
p=90;
p=p/100;
p_w_sub=p;
%p=input('SUPERSONIC REGIME: ');  %[%] percentage of wetted wing
p=95;
p=p/100;
p_w_sup=p;

disp(' ')
disp('Percentage of laminar flow on the Wing [%] :')
disp('Suggested value: 20%')
%perc_l_w_sub=input('SUBSONIC REGIME');
perc_l_w_sub=20;


disp(' ')
disp('--> TAIL <--')
disp(' ')
disp('Tail Root chord  [m]:')
cr_t=10;  %[m] root chord or lenght tail
%cr_t=input('');

disp(' ')
disp('Tail Height [m]:')
h_t=6.25; %[m] height tail
%h_t=input('');

disp(' ')
disp('Percentage Tail Wetted Area:')
%p=input('SUBSONIC REGIME'); %[%] percentage of wetted tail
p=90;
p=p/100;
p_t_sub=p;
%p=input('SUPERSONIC REGIME'); %[%] percentage of wetted tail
p=98;
p=p/100;
p_t_sup=p;

disp(' ')
disp('Percentage of laminar flow on the Tail [%] :')
disp('Suggested value: 20%')
%perc_l_t_sub=input('SUBSONIC REGIME');
perc_l_t_sub=20;


disp('--> ENGINE <--')
disp(' ')
disp('Engine Length  [m]:')
l_n=5;    %[m] Engine lenght
%l_n=input('');

disp(' ')
disp('Engine External Diameter  [m]:')
d_n=2; %1.33; %[m] diameter of fan; Wikipedia
%d_n=input('');

disp(' ')
disp('Percentage Nacelle Wetted Area:')
%p=input('SUBSONIC REGIME');    %percentage of wetted engine
p=70;
p=p/100;                  
p_n_sub=p;
%p=input('SUPERSONIC REGIME');    %percentage of wetted engine
p=80;
p=p/100;                  
p_n_sup=p;

disp('Insert a value of Thrust Available for adopted Engine (only one) [kN]:')
%TA_OE=input('');
TA_OE=90; %[kN] CONCEPT
%TA_OE=140; %[kN] CONCORDE

disp(' ')
disp('Percentage of laminar flow on the Nacelle/Engines [%] :')
disp('Suggested value: 10%')
%perc_l_n_sub=input('SUBSONIC REGIME: ');
perc_l_n_sub=10;

disp('--> AIRCRAFT AND FUSELAGE <--')
disp(' ')

disp('Aicraft lenght  [m]:')
l_ac=60;            %[m] fuselage+nose+tail lenght ; Refernce web site Boom
%l_ac=input('');

disp(' ')
disp('Fuselage Diameter  [m]:')
disp('Do you want insert the INTERNAL or EXTERNAL diameter?')
disp('If you introduce the INTERNAL one, it is incremented by 50 cm.')
disp('1.INTERNAL   2.EXTERNAL')
c_d=input('');

if c_d==1
    d_int=2.95; %[m] internal diameter; Green Concorde Reference [Estimation on the paper]
    %d_int=input(''Insert a value of Fuselage Internal Diameter'');
    d_ext=d_int+0.5; %[m] external diameter 
end

if c_d==2
    d_ext=input('Insert a value of Fuselage External Diameter');
    d_int=d_ext-0.5; %[m] internal diameter 
end

disp(' ')
disp('Percentage Fuselage Wetted Area:')
%p=input('SUBSONIC REGIME');  %percentage of wetted fuselage
p=80;
p=p/100;                 
p_f_sub=p;
%p=input('SUPERSONIC REGIME');  %percentage of wetted fuselage
p=90;
p=p/100;                 
p_f_sup=p;

disp(' ')
disp('Percentage of laminar flow on the Fuselage [%] :')
disp('Suggested value: 10%')
%perc_l_f_sub=input('SUBSONIC REGIME: ');
perc_l_f_sub=10;

disp(' ')
disp('--> OTHER PARAMETERS <--')
disp(' ')
disp('Roughness factor  [ft]:')
disp('Choose a value from the table. ')
disp('!! ATTENTION: The value chocen is applied for the all part of aricraft considered. !!')
SRV=imread('Skin_roughness_value.png');
figure (31)
imshow(SRV)
k=0.17e-5*0.3048; %[m] smooth molded composite; same values for all elements
%k=input('');
%k=k*1e-5*0.3048; %[m]
close figure 31

%WING and TAIL
disp(' ')
disp('Chordwise Location of the Airfoil Maximum Thickness (x/c):')
disp('Suggested value for high speed airfoil: 0.5')
x_c=0.5;  %x/c
%x_c=input('');

disp(' ')
disp('Profile Thickness on Chord Ratio  (t/c):')
disp('Suggested value for high speed airfoil: 0.05')
t_c=0.05; %t/c assumption cause superosnic profile
%t_c=input('');

disp(' ')
disp('--> DRAG COMPONENT <--')

disp(' ')
disp('Percentage of MISCELLANEOUS drag [%]:')
p_md_sub=0.05; %percentage of Miscellaneous drag
% p_md_sub=input('SUBSONIC REGIME');
% p_md_sub=p_md_sub/100;
p_md_sup=0.05; %percentage of Miscellaneous drag
% p_md_sup=input('SUPERSONIC REGIME');
% p_md_sup=p_md_sup/100;


disp(' ')
disp('Percentage of LEAKAGES AND PROTUBERANCE drag [%]:')
p_lp_sub=0.05; %percentage of Leakange and protuberance drag
% p_lp_sub=input('SUBOSNIC REGIME');
% p_lp_sub=p_lp_sub/100;
p_lp_sup=0.05; %percentage of Leakange and protuberance drag
% p_lp_sup=input('SUBOSNIC REGIME');
% p_lp_sup=p_lp_sup/100;

disp(' ')
disp('--> DINAMIC VISCOSITY <--')
disp(' ')
disp('Insert a value of Dinamic Viscosity and relative altitude REFERRED TO SUBSONIC CRUISE PHASE:')
disp('!! ATTENTION: Dinamic Viscousity is estimated through linear variation between two altitude values. !!')
disp('!! ATTENTION: If the cruise has a constant altitude you only must repeat the value. !!')
mu_start=1.63e-5;
h_start=5000;
mu_end=1.46e-5;
h_end=10000;
% h_start=input('Starting Altitude: ' );
% mu_start=input('Dinamic Viscosity at Starting Altitude: ' );
% h_end=input('Ended Altitude: ' );
% mu_end=input('Dinamic Viscosity at Ended Altitude: ' );


%% ESTIMATED PARAMETERS
disp(' ')
disp(' FIRST OUTPUTS ESTIMATED SECTION: ')

disp(' ')
AR=b^2/WS;
disp(['Aspect Ratio (AR): ',num2str(AR)])

[MAC_w,MAC_t,sweep_t_d, sweep_t_r] = MeanAerodynamicChord(b,d_ext,cr_w,h_t,cr_t);
disp(' ')
disp(['Wing MAC:',num2str(MAC_w),' m'])
disp(['Tail MAC:',num2str(MAC_t),' m'])
disp(['Tail sweep angle:',num2str(sweep_t_d),' ° '])

h_v=fl3:1:fl4;  %REFERENCE PHASE: SUBSONIC CRUISE. RANGE OF VARIATION
M=Msub;
Vnum=0; RHOnum=0; 
contV=0; contRHO=0;

for i=1:length(h_v)
    h=h_v(i);
    [V] = Speed(h,M);
    contV=contV+1;
    Vnum=Vnum+V;
        
        
    rho=1.226*(1-0.0000226*h)^4.256; %[kg/m3] Standard Atmosphere - Troposphere
    contRHO=contRHO+1;
    RHOnum=RHOnum+rho;
    
    mu=mu_start+(mu_end-mu_start)*(h-h_start)/(h_end-h_start); %[Pa*s] Linear variation of dinamic viscosity between 5000 and 10000 m
end
Vsub_crs=Vnum/contV;       %Arithmetic average SPEED SUBSONIC CRUISE
rhosub_crs=RHOnum/contRHO; %Aritmet average    DENSITY SUBSONIC CRUISE
musub_crs=mu;              %Linear variation   DINAMIC VISCOSITY SUBSONIC CRUISE
disp(' ')
disp(['Subsonic Cruise Speed:',num2str(Vsub_crs),' m/s'])
disp(['Subsonic Cruise Density:',num2str(rhosub_crs),' kg/m3'])
disp(['Dinamic viscosity:',num2str(mu),' Pa*s '])

disp(' ')
GainFactor=NT/TA_OE; %How much engines need to assure the total thrust estimated in statistical analysis
disp(['#engine estimated:',num2str(round(GainFactor))])
%% LIFT
disp('.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.--.-.-.-.-.-.--.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.')
disp('                                           LIFT                                            ')

%SUBSONIC
beta=sqrt(1-Msub^2); 
[Sratio, Sref, Scov, Sexp,c_SRM] = SurfaceRatio(b,cr_w,d_ext,WS);

% disp(' ')
% disp(['Sexposed [half wing exposed, bottom or upper part] ',num2str(Sexp),' m2'])

%FUSELAGE LIFT FACTOR
F=1.07*(1+d_ext/b)^2;

%Lift-curve slope 

Clalfa_sub=(2*pi*AR)/(2+sqrt(4+(AR*beta/eta)^2*(1+(tan(sweep_w_r)/beta)^2)))*Sratio*F;
disp(' ')
disp('SUBSONIC')
disp(['CLalfa:',num2str(Clalfa_sub)])

% Lift coefficient
CL_sub=Clalfa_sub*alfasub;   %CONSTRAIN: LINEAR REGION CL-ALFA, ALFA MUST BE LESS THAN STALL ANGLE
disp(' ')
disp(['CL :',num2str(CL_sub)])

% SUPERSONIC
Clalfa_sup=4/sqrt(Msup^2-1);

disp(' ')
disp('SUPERSONIC')
disp(['CLalfa:',num2str(Clalfa_sup)])

% Lift coefficient
CL_sup=Clalfa_sup*alfasup;
disp(' ')
disp(['CL :',num2str(CL_sup)])
%% DRAG

disp('.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.--.-.-.-.-.-.--.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.')
disp('                                           DRAG                                            ')

%% 1. SUBSONIC

disp(' ')
disp('1. SUBSONIC')

%% 1.1 PARASSITE DRAG: TO ESTIMATE FOR MAIN COMPONENT: WING, TAIL, FUSELAGE AND NACELLES
disp(' ')
disp('1.1 PARASITE DRAG')

%% PARASSITE DRAG -FIRST TERM: 
%REYNOLDS: 'NORMAL' (n) and CUT-OFF (ct)
%[Cf] FLAT PLANE SKIN FRICTION COEFFICIENT: LAMINAR (l) AND TURBOLENT (t)
%[FF] FORM FACTOR
%[Q] INTERFERENCE FACTOR
%[SWET] WETTED SURFACE
disp('-------------------------------------------------------------------')

%% FUSELAGE
disp('--> FUSELAGE <--')

Re_n_f=rhosub_crs*Vsub_crs*l_ac/musub_crs;                          %Normal Reynold 
Re_ct_f=38.21*(l_ac/k)^1.053;                                       %Cut off Raynold 
disp(['Reynolds :',num2str(Re_n_f)])
disp(['Reynolds CUT OFF:',num2str(Re_ct_f)])
Cf_l_f=1.328/sqrt(Re_n_f);                                          %Cf laminar 
Cf_t_f=0.455/(log(min(Re_n_f,Re_ct_f))^2.58*(1+0.144*Msub^2)^0.65); %Cf turbolent 
disp(' ')
disp(['Cf laminar :',num2str(Cf_l_f)])
disp(['Cf turbolent :',num2str(Cf_t_f)])

Cf_f=perc_l_f_sub/100*Cf_l_f+(1-perc_l_f_sub/100)*Cf_t_f;           %'Weighted' Cf
disp(['Weighted Cf :',num2str(Cf_f)])

f=l_ac/d_ext; 
FF_f=1+60/f^3+f/400;                                                %Form Factor
disp(' ')
disp(['FF :',num2str(FF_f)])

SRV=imread('Interference_factor_Q.png');
figure (32)
imshow(SRV)

disp('Insert a value for Interference Factor for FUSELAGE')
disp('FIGURE 32 shows possible values. ')
%Q_f=input('');
Q_f=1; 
disp(' ')
disp('FUSELAGE')
disp(['Q :',num2str(Q_f)])

Swet_f=(2*pi*l_ac*d_ext/2)*p_f_sub;                                 %Wetted surface %SOVRASTIMA LA SUPERFICIE POICHè INDIVIFUA UN CILINDRO CHE VA DAL NOSE AL TAIL
%disp(['Cilinder surface fuselage ',num2str(2*pi*lf*d/2),' m2'])
disp(['Swet :',num2str(Swet_f)])
%% WING
disp(' ')
disp('--> WING <--')

Re_n_w=rhosub_crs*Vsub_crs*MAC_w/musub_crs;                         %Normal Reynold 
Re_ct_w=38.21*(MAC_w/k)^1.053;                                      %Cut off Raynold
disp(['Reynolds :',num2str(Re_n_w)])
disp(['Reynolds CUT OFF :',num2str(Re_ct_w)])
Cf_l_w=1.328/sqrt(Re_n_w);                                          %Cf laminar 
Cf_t_w=0.455/(log(min(Re_n_w,Re_ct_w))^2.58*(1+0.144*Msub^2)^0.65); %Cf turbolent
disp(['Cf laminar :',num2str(Cf_l_w)])
disp(['Cf turbolent: ',num2str(Cf_t_w)])

Cf_w=perc_l_w_sub/100*Cf_l_w+(1-perc_l_w_sub/100)*Cf_t_w;               %Weighted Cf
disp(['Weighted Cf :',num2str(Cf_w)])

FF_w=(1+0.6/x_c*t_c+100*t_c^4)*(1.34*Msub^0.18*(cos(sweep_w_r))^0.28); %Form Factor
disp(['FF :',num2str(FF_w)])

disp('Insert a value for Interference Factor for WING')
disp('FIGURE 32 shows possible values. ')
%Q_w=input('');
Q_w=1;     %high wing, mid wing, well-filleted low wing
disp(' ')
disp('WING')
disp(['Q :',num2str(Q_w)])

Swet_w=(p_w_sub*Sexp)*4;                                                %Wetetd Surface %4 factor means bottom and up of the semi-wing and both of semi-wing
disp(['Swet :',num2str(Swet_w)])
%% TAIL
disp(' ')
disp('--> TAIL <--')

Re_n_t=rhosub_crs*Vsub_crs*MAC_t/musub_crs;                         %Normal Reynold 
Re_ct_t=38.21*(MAC_t/k)^1.053;                                      %Cut off Raynold
disp(['Reynolds :',num2str(Re_n_t)])
disp(['Reynolds CUT OFF :',num2str(Re_ct_t)])
Cf_l_t=1.328/sqrt(Re_n_t);                                          %Cf laminar 
Cf_t_t=0.455/(log(min(Re_n_t,Re_ct_t))^2.58*(1+0.144*Msub^2)^0.65); %Cf turbolent 
disp(['Cf laminar :',num2str(Cf_l_t)])
disp(['Cf turbolent: ',num2str(Cf_t_t)])

Cf_t=perc_l_t_sub/100*Cf_l_t+(1-perc_l_t_sub/100)*Cf_t_t;            %Weighted Cf
disp(['Weighted Cf :',num2str(Cf_t)])

FF_t=(1+0.6/x_c*t_c+100*t_c^4)*(1.34*Msub^0.18*(cos(sweep_t_r))^0.28); %Form Factor
FF_t=FF_t*(1+0.1);                                                     %increas of 10% caused by hinges for control surface
disp(['FF :',num2str(FF_t)])

disp('Insert a value for Interference Factor for TAIL')
disp('FIGURE 32 shows possible values. ')
%Q_t=input('');
Q_t=1.045; %conventional tail
disp(' ')
disp('TAIL')
disp(['Q :',num2str(Q_t)])

Str=cr_t*h_t/2;        %Ideal Triangle surface 
% disp(' ')
% disp(['Triangle surface [one part of tail] ',num2str(Str),' m2'])
Sexp_t=Str*(1+0.05);   %Trapezoidal surface; assumption of 5% of incrementation

Swet_t=(p_t_sub*Sexp_t)*2; %2 factor means both side of tail
disp(['Swet:',num2str(Swet_t)])

%% ENGINE
disp(' ')
disp('--> ENGINE/NACELLE <--')

Re_n_n=rhosub_crs*Vsub_crs*l_n/musub_crs;                           %Normal Reynold 
Re_ct_n=38.21*(l_n/k)^1.053;                                        %Cut off Raynold 
disp(['Reynolds:',num2str(Re_n_n)])
disp(['Reynolds CUT OFF :',num2str(Re_ct_n)])
Cf_l_n=1.328/sqrt(Re_n_n);                                          %Cf laminar 
Cf_t_n=0.455/(log(min(Re_n_n,Re_ct_n))^2.58*(1+0.144*Msub^2)^0.65); %Cf turbolent 
disp(['Cf laminar :',num2str(Cf_l_n)])
disp(['Cf turbolent ',num2str(Cf_t_n)])

Cf_n=perc_l_n_sub/100*Cf_l_n+(1-perc_l_n_sub/100)*Cf_t_n;           %Weigthed 
disp(['Weighted Cf :',num2str(Cf_n)])

f=l_n/d_n;
FF_n=1+0.35/f;                                                      %Form Factor
disp(['FF :',num2str(FF_n)])

disp('Insert a value for Interference Factor for ENGINE/NACELLE')
disp('FIGURE 32 shows possible values. ')
%Q_n=input('');
Q_n=1.5;
disp(' ')
disp('NACELLE')
disp(['Q :',num2str(Q_n)])

close figure 32

Swet_n=round(GainFactor)*p_n_sub*(2*pi*l_n*d_n/2);                      %Gain factor: 4 factor implies 4 engines of GE affinity 
%disp(['Cilinder surface nacelle ',num2str(2*pi*ln*dn/2),' m2'])
disp(['Swet :',num2str(Swet_n)])

%% 1.1 PARASSITE DRAG: FIRST TERM + MISCELLANEOUS DRAG + LEAKAGES AND PROTUBERANCES DRAG
Iterm_sub=((Cf_w*FF_w*Q_w*Swet_w)+(Cf_t*FF_t*Q_t*Swet_t)+(Cf_f*FF_f*Q_f*Swet_f)+(Cf_n*FF_n*Q_n*Swet_n))/Sref;

disp(['FIRST TERM OF PARASITE DRAG :',num2str(Iterm_sub)])

CD0_sub=Iterm_sub/(1-p_md_sub-p_lp_sub);
disp(' ')
disp(['PARASITE DRAG [Build up method] :',num2str(CD0_sub)])

%% COMPARISON PARASSITE DRAG: EQUIVALENT SKIN FRICTION METHOD (to check the build up method) --> SOLO PER REPORT

Cfe=0.0030;

CD0_esf=Cfe*Swet_w/Sref;
disp(['PARASITE DRAG [Equivalent skin friction method] :',num2str(CD0_esf)])

%% 1.2 DRAG DUE TO LIFT : INDUCED , VISCOUS SEPARATION AND VARATION OF PARASITE DRAG
disp('-------------------------------------------------------------------')

disp('1.2 DRAG DUE TO LIFT')

%% Ostwald wing span efficiency method 
disp('Ostwald Wing Span Efficiency method')

e=(4.61*(1-0.045*AR^0.68)*((cos(sweep_w_r))^0.15))-3.1; %Ostawald factor:Raymer formulation for sweep wing with sweep angle >30°
disp(['Ostwald factor :',num2str(e)])

%Drag due to lift factor
Kq=1/(pi*AR*e);
disp(['K [Oswald wing span method] :',num2str(Kq)])

CDi_O=Kq*CL_sub^2;
disp(' ')
disp(['CDi [Oswald wing span method]:',num2str(CDi_O)])

%% Leading edge suction method
disp('Leading Edge Suction Method')

K0=1/Clalfa_sub;
K100=1/(pi*AR);
disp(' ')
disp('Insert a Leading Edge Suction Factor:')
disp('Suggested range: 0.85 - 0.95')
disp('!! ATTENTION: The values will be the same of supersonic regime. !!')
%S_c=input('');
S_c=0.85; %LE suction factor

disp(' ')
disp(['K0 ',num2str(K0)])
disp(['K100 ',num2str(K100)])

Ks=S_c*K100+(1-S_c)*K0;
disp(['K [Leading edge suction method] :',num2str(Ks)])

CDi_s=Ks*CL_sub^2;
disp(' ')
disp(['CDi [Leading edge suction method]:',num2str(CDi_s)])

%% 1. SUBSONIC DRAG
disp('-------------------------------------------------------------------')
disp('                           SUBSONIC DRAG                           ')

CD_O_sub=CD0_sub+CDi_O;
CD_s_sub=CD0_sub+CDi_s;
disp(['CD [Oswald wing span method]:',num2str(CD_O_sub)])
disp(['CD [Leading edge suction method]:',num2str(CD_s_sub)])


%% 2. SUPERSONIC 
disp('-------------------------------------------------------------------')
disp('2. SUPERSONIC')

%% 2.1.1 PARASITE DRAG FIRST TERM: TO ESTIMATE FOR MAIN COMPONENT: WING, TAIL, FUSELAGE AND NACELLES

disp(' ')
disp('2.1 PARASSITE')

%% PARASSITE DRAG -FIRST TERM: 
%REYNOLDS:  CUT-OFF (ct)
%[Cf] FLAT PLANE SKIN FRICTION COEFFICIENT: TURBOLENT (t)
%[SWET] WETTED SURFACE
disp('-------------------------------------------------------------------')
%% FUSELAGE 
disp(' ')
disp('--> FUSELAGE <--')
Re_ct_f=44.62*(l_ac/k)^1.053*Msup^1.16;               %Cut off Raynold
disp(['Reynolds CUT OFF:',num2str(Re_ct_f)])
Cf_f=0.455/(log(Re_ct_f)^2.58*(1+0.144*Msup^2)^0.65); %Cf turbolent 
disp(['Cf :',num2str(Cf_f)])

Swet_f=(2*pi*l_ac*d_ext/2)*p_f_sup; 
disp(' ')
disp('FUSELAGE')
disp(['Swet:',num2str(Swet_f)])
%% WING
disp(' ')
disp('--> WING <--')

Re_ct_w=44.62*(MAC_w/k)^1.053*Msup^1.16;              %Cut off Raynold 
disp(['Reynolds CUT OFF:',num2str(Re_ct_w)])
Cf_w=0.455/(log(Re_ct_w)^2.58*(1+0.144*Msup^2)^0.65); %Cf turbolent for wing
disp(['Cf :',num2str(Cf_w)])

Swet_w=(p_w_sup*Sexp)*4;                              %Wetted Surafce %4 factor means bottom and up of the semi-wing and both of semi-wing
disp(' ')
disp(['Swet:',num2str(Swet_w)])
%% TAIL
disp(' ')
disp('--> TAIL <--')

Re_ct_t=44.62*(MAC_t/k)^1.053*Msup^1.16;              %Cut off Raynold 
disp(['Reynolds CUT OFF :',num2str(Re_ct_t)])
Cf_t=0.455/(log(Re_ct_t)^2.58*(1+0.144*Msup^2)^0.65); %Cf turbolent 
disp(['Cf :',num2str(Cf_t)])

Swet_t=(p_t_sup*Sexp_t)*2;                            %Wetted Surafce %2 factor means both side of tail
disp(' ')
disp(['Swet:',num2str(Swet_t)])
%% ENGINE/NACELLE
disp(' ')
disp('--> ENGINE/NACELLE <--')

Re_ct_n=44.62*(l_n/k)^1.053*Msup^1.16;                %Cut off Raynold 
disp(['Reynolds CUT OFF :',num2str(Re_ct_n)])
Cf_n=0.455/(log(Re_ct_n)^2.58*(1+0.144*Msup^2)^0.65); %Cf turbolent 
disp(['Cf :',num2str(Cf_n)])

Swet_n=round(GainFactor)*p_n_sup*(2*pi*l_n*d_n/2);          %Wettwd Surface %4 factor implies 4 engines of GE affinity 
disp(' ')
disp(['Swet:',num2str(Swet_n)])
%% 2.1.2 WAVE DRAG
disp('-------------------------------------------------------------------')
disp('                            WAVE DRAG                              ')
disp(' ')

Af=pi*(d_ext/2)^2;
disp(['Fuselage cross sectional area:',num2str(Af),'m2'])
disp(' ')

An=round(GainFactor)*pi*(d_n/2)^2;
disp(['Engines/Nacelle cross sectional area:',num2str(An),'m2'])
disp(' ')

Amax=(Af+An)/(1-0.25);                             %[m2], fuselage ,nacelle (x4) and %contribute (25%) of wing (2/3 of wing, main landing gear location)
disp(['Maximum cross sectional area:',num2str(Amax),'m2'])
disp(' ')

Dq_SH=9*pi/2*(Amax/l_ac)^2;
disp(['D/q Seras-Haack ',num2str(Dq_SH),' m2'])

SRV=imread('Wave_Drag_Ewd.png');
figure (33)
imshow(SRV)
disp('Insert a value for WAVE DRAG EFFICIENCY FACTOR for FUSELAGE')
disp('FIGURE 33 shows possible values. ')
%Ewd=input('');
Ewd=1.2;                                           %Wave-drag efficiency factor [‘blended delta wing’ ]
close figure 33

Dq_w=Dq_SH*Ewd*(1-0.2*(Msup-1.2)^0.57*(1-((pi*sweep_w_d^0.77)/100)));
disp(['D/q Wave ',num2str(Dq_w),' m2'])

CD_w=Dq_w/Sref;
disp(['CDw:',num2str(CD_w)])
%% 2.1 PARASSITE DRAG: FIRST TERM + MISCELLANEOUS DRAG + LEAKAGES AND PROTUBERANCES DRAG + WAVE DRAG
disp('-------------------------------------------------------------------')

Iterm_sup=((Cf_w*Swet_w)+(Cf_t*Swet_t)+(Cf_f*Swet_f)+(Cf_n*Swet_n))/Sref;

disp(['FIRST TERM OF PARASITE DRAG :',num2str(Iterm_sup)])

CD0_sup=(Iterm_sup+CD_w)/(1+p_md_sup+p_lp_sup);

disp(' ')
disp('Parasite drag in SUPERSONIC')
disp(['CD0:',num2str(CD0_sup)])

%% 2.2 DRAG DUE TO LIFT: INDUCED , VISCOUS SEPARATION AND VARATION OF PARASITE DRAG

disp('-------------------------------------------------------------------')
disp('2.2 DRAG DUE TO LIFT')

%% Ostwald span efficiency method
Kq=(AR*(Msup^2-1)*cos(sweep_w_r))/(4*AR*sqrt(Msup^2-1)-2);
disp(['K [Ostwald span efficiency method] :',num2str(Kq)])
CDi_O_sup=Kq*CL_sup^2;
disp(['CDi [Ostwald span efficiency method]:',num2str(CDi_O_sup)])
%% Leading edge suction method
K=1/Clalfa_sup;
%S=0.85; %LE suction factor
disp(['K0 ',num2str(K)])
Ks=S_c*K+(1-S_c)*K;
disp(['K [Leading edge suction method] :',num2str(Ks)])
CDi_s_sup=Ks*CL_sup^2;
disp(['CDi [Leading edge suction approach]:',num2str(CDi_s_sup)])

%% 2. SUPERSONIC DRAG
disp('-------------------------------------------------------------------')
disp('                           SUPERSONIC DRAG                         ')

CD_O_sup=CD0_sup+CDi_O_sup;
CD_s_sup=CD0_sup+CDi_s_sup;

disp(['CD [Ostwald span efficiency method]:',num2str(CD_O_sup)])
disp(['CD [Leading edge suction method]:',num2str(CD_s_sup)])

%% AERODINAMIC EFFICIENCY IN SUBSONIC CRUISE

disp('-------------------------------------------------------------------')
disp('                        AERODINAMIC EFFICIENCY                     ')
disp('1.SUBSONIC')
E_O_sub=CL_sub/CD_O_sub;
disp(['E [Oswald wing span method]:',num2str(E_O_sub)])
E_s_sub=CL_sub/CD_s_sub;
disp(['E [Leading edge suction method]:',num2str(E_s_sub)])

disp(' ')
disp('1.SUPERSONIC')
E_O_sup=CL_sup/CD_O_sup;
E_s_sup=CL_sup/CD_s_sup;
disp(['E [Ostwald span efficiency method]:',num2str(E_O_sup)])
disp(['E [Leading edge suction method]:',num2str(E_s_sup)])

disp(' ')
disp('Chose a value of aerodynamic efficiency for BOTH (SUBSONIC AND SUPERSONIC) regimes.')
disp(['1.[Oswald wing span method]: SUBSONIC-->',num2str(E_O_sub),' ; SUPERSONIC-->',num2str(E_O_sup)])
disp(['2.[Leading edge suction method]:  SUBSONIC-->',num2str(E_s_sub),' ; SUPERSONIC-->',num2str(E_s_sup)])
eff=input('');

if eff==1 %Ostwald
    E_sub=E_O_sub;
    CD_sub=CD_O_sub;
    
    E_sup=E_O_sup;
    CD_sup=CD_O_sup;
end

if eff==2 %Leading
    E_sub=E_s_sub;
    CD_sub=CD_s_sub;
    
    E_sup=E_s_sup;
    CD_sup=CD_s_sup;
end

disp('-------------------------------------------------------------------')

end

