function [E_sub,E_sup,CL_sub, CL_sup,CD_sub,CD_sup,CD0_sub,CD0_sup,AR,e]=Aerodynamics_Loop(C_HyLH2,eff,S,c_SRM,Msub,Msup,alfasub,alfasup,eta,sweep_w_d,sweep_w_r,...
         l_ac,cr_w,b,d_ext,cr_t,h_t,l_n,d_n,GainFactor,rhosub_crs,Vsub_crs,musub_crs,k,perc_l_f_sub,perc_l_w_sub,perc_l_t_sub,perc_l_n_sub,p_f_sub,p_w_sub,...
         p_t_sub,p_n_sub,p_f_sup,p_w_sup,p_t_sup,p_n_sup,x_c,t_c,p_md_sub,p_lp_sub,p_md_sup,p_lp_sup,S_c,Ewd,Q_w,Q_f,Q_t,Q_n)

 %AERODYNAMIC ANALYSIS FROM SECOND ITERATION 

%% AERODYNAMIC

%% LIFT

beta=sqrt(1-Msub^2); 

%INPUT: eta

%INPUT: sweep_w_d,sweep_w_r

if C_HyLH2==1  %IDROCARBON PROJECT
    
    %Aspect  ratio-UPDATE
    AR=b^2/S;
    
%     disp(' ')
%     disp('Aerodynamics_RV_TS')
%     disp(['Aircraft length: ',num2str(lf),' m'])
%     disp(['Wing Root chord: ',num2str(cr),' m'])
%     disp(['Wing span: ',num2str(b),' m'])
%     disp(['External diameter ',num2str(d),' m'])
%     disp(['Tail Root chord: ',num2str(crt),' m'])
%     disp(['Tail heigth: ',num2str(lt),' m'])
%     disp(['Aspect ratio [b2/S]: ',num2str(AR)])
    
end

if C_HyLH2==2  %LH2 PROJECT  
    
    %wing root chord -UPDATE
    cr_w=0.5*l_ac;
    
    %wing span -UPDATE
    b=0.89*cr_w;
    
    %External diamter -UPDATE
    %d=d_int;
    
    %tail root chord -UPDATE
    cr_t=0.2*l_ac;
    
    %tail heigth -UPDATE
    h_t=0.79*cr_t;
    
    %Aspect  ratio-UPDATE
    AR=b^2/S;

    
end
 
[Sratio, Sexp] = SurfaceRatio_Loop(b,cr_w,d_ext,S,c_SRM);

%FUSELAGE LIFT FACTOR
F=1.07*(1+d_ext/b)^2;

%% SUBSONIC
Clalfa_sub=(2*pi*AR)/(2+sqrt(4+(AR*beta/eta)^2*(1+(tan(sweep_w_r)/beta)^2)))*Sratio*F;
CL_sub=Clalfa_sub*alfasub;
%% SUPERSONIC
Clalfa_sup=4/sqrt(Msup^2-1);
CL_sup=Clalfa_sup*alfasup;
%% DRAG
%% 1. SUBSONIC

[MAC_w,MAC_t,sweep_t_d, sweep_t_r] = MeanAerodynamicChord(b,d_ext,cr_w,h_t,cr_t);

%rho,mu e V sub_crs from Aerodynamics.m

%FUSELAGE
Re_n_f=rhosub_crs*Vsub_crs*l_ac/musub_crs;         %Normal Reynold for fuselage
Re_ct_f=38.21*(l_ac/k)^1.053; %Cut off Raynold for fuselage
Cf_l_f=1.328/sqrt(Re_n_f);                                          %Cf laminar for fuselage
Cf_t_f=0.455/(log(min(Re_n_f,Re_ct_f))^2.58*(1+0.144*Msub^2)^0.65); %Cf turbolent for fuselage
Cf_f=perc_l_f_sub/100*Cf_l_f+(1-perc_l_f_sub/100)*Cf_t_f;  %Fuselage
f=l_ac/d_ext; 
FF_f=1+60/f^3+f/400;
p=p_f_sub;
Swet_f=(2*pi*l_ac*d_ext/2)*p; 

%WING
Re_n_w=rhosub_crs*Vsub_crs*MAC_w/musub_crs;         %Normal Reynold for wing
Re_ct_w=38.21*(MAC_w/k)^1.053; %Cut off Raynold for wing
Cf_l_w=1.328/sqrt(Re_n_w);                                          %Cf laminar for wing
Cf_t_w=0.455/(log(min(Re_n_w,Re_ct_w))^2.58*(1+0.144*Msub^2)^0.65); %Cf turbolent for wing
Cf_w=perc_l_w_sub/100*Cf_l_w+(1-perc_l_w_sub/100)*Cf_t_w;  %Wing
FF_w=(1+0.6/x_c*t_c+100*t_c^4)*(1.34*Msub^0.18*(cos(sweep_w_r))^0.28);
p=p_w_sub;
Swet_w=(p*Sexp)*4;  %4 factor means bottom and up of the semi-wing and both of semi-wing

%TAIL
Re_n_t=rhosub_crs*Vsub_crs*MAC_t/musub_crs;         %Normal Reynold for tail
Re_ct_t=38.21*(MAC_t/k)^1.053; %Cut off Raynold for tail
Cf_l_t=1.328/sqrt(Re_n_t);                                       %Cf laminar for tail
Cf_t_t=0.455/(log(min(Re_n_t,Re_ct_t))^2.58*(1+0.144*Msub^2)^0.65); %Cf turbolent for tail
Cf_t=perc_l_t_sub/100*Cf_l_t+(1-perc_l_t_sub/100)*Cf_t_t;  %Tail
FF_t=(1+0.6/x_c*t_c+100*t_c^4)*(1.34*Msub^0.18*(cos(sweep_t_r))^0.28);
Str=cr_t*h_t/2;        %Ideal Triangle surface 
Sexp_t=Str*(1+0.05); %Trapezoidal surface; assumptio of 5% of incrementation
p=p_t_sub;
Swet_t=(p*Sexp_t)*2; %2 factor means both side of tail

%NACELLE
Re_n_n=rhosub_crs*Vsub_crs*l_n/musub_crs;         %Normal Reynold for nacelle
Re_ct_n=38.21*(l_n/k)^1.053; %Cut off Raynold for nacelle
Cf_l_n=1.328/sqrt(Re_n_n);                                       %Cf laminar for nacelle
Cf_t_n=0.455/(log(min(Re_n_n,Re_ct_n))^2.58*(1+0.144*Msub^2)^0.65); %Cf turbolent for nacelle
Cf_n=perc_l_n_sub/100*Cf_l_n+(1-perc_l_n_sub/100)*Cf_t_n;  %Nacelle
f=l_n/d_n;
FF_n=1+0.35/f;
p=p_n_sub;
Swet_n=round(GainFactor)*p*(2*pi*l_n*d_n/2);%Gain factor: 4 factor implies 4 engines of GE affinity

%PARASSITE DRAG: FIRST TERM OF CD0
It=((Cf_w*FF_w*Q_w*Swet_w)+(Cf_t*FF_t*Q_t*Swet_t)+(Cf_f*FF_f*Q_f*Swet_f)+(Cf_n*FF_n*Q_n*Swet_n))/S;
%PARASSITE DRAG: CD0 
CD0_sub=It/(1-p_md_sub-p_lp_sub);

% 1.2 DRAG DUE TO LIFT : INDUCED , VISCOUS SEPARATION AND VARATION OF PARASITE DRAG
e=(4.61*(1-0.045*AR^0.68)*((cos(sweep_w_r))^0.15))-3.1; %Ostawald factor:Raymer formulation for sweep wing with sweep angle >30°

if  eff==1  %OSTWALD SPAN EFFICIENCY METHOD
    Kq=1/(pi*AR*e);
    CDi=Kq*CL_sub^2;
    CD_sub=CD0_sub+CDi;
    E_sub=CL_sub/CD_sub;
end

if  eff==2   %Leading edge suction method
    K0=1/Clalfa_sub;
    K100=1/(pi*AR);
    %S=0.85; %LE suction factor
    Ks=S_c*K100+(1-S_c)*K0; 
    CDi=Ks*CL_sub^2;
    CD_sub=CD0_sub+CDi;
    E_sub=CL_sub/CD_sub;
end

%% 2. SUPERSONIC 
% 2.1 PARASITE DRAG: TO ESTIMATE FOR MAIN COMPONENT: WING, TAIL, FUSELAGE AND NACELLES

%FUSELAGE
Re_ct_f=44.62*(l_ac/k)^1.053*Msup^1.16;   %Cut off Raynold for fuselage
Cf_f=0.455/(log(Re_ct_f)^2.58*(1+0.144*Msup^2)^0.65); %Cf turbolent for fuselage
p=p_f_sup;
Swet_f=(2*pi*l_ac*d_ext/2)*p; 

%WING
Re_ct_w=44.62*(MAC_w/k)^1.053*Msup^1.16; %Cut off Raynold for wing
Cf_w=0.455/(log(Re_ct_w)^2.58*(1+0.144*Msup^2)^0.65); %Cf turbolent for wing
p=p_w_sup;
Swet_w=(p*Sexp)*4; %4 factor means bottom and up of the semi-wing and both of semi-wing

%TAIL
Re_ct_t=44.62*(MAC_t/k)^1.053*Msup^1.16; %Cut off Raynold for tail
Cf_t=0.455/(log(Re_ct_t)^2.58*(1+0.144*Msup^2)^0.65); %Cf turbolent for tail
p=p_t_sup;
Swet_t=(p*Sexp_t)*2; %2 factor means both side of tail

%NACELLE
Re_ct_n=44.62*(l_n/k)^1.053*Msup^1.16;    %Cut off Raynold for nacelle
Cf_n=0.455/(log(Re_ct_n)^2.58*(1+0.144*Msup^2)^0.65); %Cf turbolent for nacelle
p=p_n_sup;
Swet_n=round(GainFactor)*p*(2*pi*l_n*d_n/2); %4 factor implies 4 engines of GE affinity 

%PARASITE DRAG: FIRST TERM OF CD0
It_sup=((Cf_w*Swet_w)+(Cf_t*Swet_t)+(Cf_f*Swet_f)+(Cf_n*Swet_n))/S;

%PARASITE DRAG: WAVE DRAG
Af=pi*(d_ext/2)^2;
An=round(GainFactor)*pi*(d_n/2)^2;
Amax=(Af+An)/(1-0.25); %[m2], fuselage ,nacelle (x4) and %contribute (25%) of wing (2/3 of wing, main landing gear location)
Dq_SH=9*pi/2*(Amax/l_ac)^2;
%Ewd=1.2; %Wave-drag efficiency factor [‘blended delta wing’ ]
Dq_w=Dq_SH*Ewd*(1-0.2*(Msup-1.2)^0.57*(1-((pi*sweep_w_d^0.77)/100)));
CD_w=Dq_w/S;

%PARASITE DRAG: CD0
CD0_sup=(It_sup+CD_w)/(1+p_md_sup+p_lp_sup);

% 2.2 DRAG DUE TO LIFT: INDUCED , VISCOUS SEPARATION AND VARATION OF PARASITE DRAG
if  eff==1 %Ostwald span efficiency method
    Kq=(AR*(Msup^2-1)*cos(sweep_w_r))/(4*AR*sqrt(Msup^2-1)-2);
    CDi_sup=Kq*CL_sup^2;
    CD_sup=CD0_sup+CDi_sup;
    E_sup=CL_sup/CD_sup;
end

if  eff==2   %Leading edge suction method
    K=1/Clalfa_sup;
    %S=0.85; %LE suction factor
    Ks=S_c*K+(1-S_c)*K;
    CDi_sup=Ks*CL_sup^2;
    CD_sup=CD0_sup+CDi_sup;
    E_sup=CL_sup/CD_sup;
end

end

