function [SFC_crs,Vc] = SFCscale(Vsub_crs,fl6,fl5,fl7,fl8,cruise,ISP,SFC,Mach_utente,C_HyLH2,Msup)

%Estimate the SFC in cruise phase through a scale factor (propulsive
%efficiency ratio) related to SFC value for statistical analysis related to main phase of the mission (supersonic
%cruise)
%ATTENTION: this function is related to mission profile WITHOUTH MISSED
%APPROACH
%ASSUMPTION: cruise is been done at costant Mach number and variable altitude
%PARAMETERS DESCRIPTION:
%   M: Mach number
%   q: vector of altitude value
%   Vm: summary of velocity value
%   cont: counter
%   h: current altitude (in the loop)
%   eta0_supercruise: propulsive efficiency in supersonic cruise
%   eta0_subcruise: propulsive efficiency in subsonic cruise
%   SFC_ref: specific fuel consumption from statistical value
%   related to superosnic cruise
%   SFC_crs:  specific fuel consumption estimeted for the specific
%   cruise phase
%   Vc: cruise velocity

%% CALORIFIC POWER PER UNIT OF MASS
HLH2=130*1e6;       %[J/kg]
Hkerosene=44.6*1e6; %[J/kg]

if C_HyLH2==1 %hydrocarbon aircraft
    H=Hkerosene;
end

if C_HyLH2==2 %lh2 aircraft
    H=HLH2;
end

%% SPECIFIC IMPULSE
Isp=ISP; %[s] statistical value

%% PHASE: SUBSONIC CRUISE

if cruise==1 
    
Vc=Vsub_crs;

end

%% PHASE: SUPERSONIC CRUISE

if cruise==2
    
M=Msup;
h_v=fl5:1:fl6;

Vm=0;
contV=0;

for i=1:length(h_v) 
    
h=h_v(i);
[V] = Speed(h,M);  %[m/s]
Vm=Vm+[V];
contV=contV+1;

end
Vc=Vm/contV;

end

%% PHASE: SUBSONIC CRUISE (DESCENT)

if cruise==3
    
disp(' ')
disp('Insert a value of Mach number  to compute speed')
M=input('');
h_v=fl7:-1:fl8;

Vm=0;
contV=0;

for i=1:length(h_v)
    
h=h_v(i);
[V] = Speed(h,M);%[m/s]
Vm=Vm+[V];

contV=contV+1;

end

Vc=Vm/contV;

end

%% SPEED REFERENCE:PROJECT REQUIREMENTS (IN THIS CASE:SUPERSONIC CRUISE)

Mref=Mach_utente;
h_v=fl5:1:fl6;
Vm=0;
contV=0;

for i=1:length(h_v)
    
h=h_v(i);
M=Mref;
[V] = Speed(h,M);%[m/s]
Vm=Vm+[V];
contV=contV+1;

end

Vref=Vm/contV;

%%
%gravity acceleration [m/s2]
g=9.81; 

eta0_ref=g/H*Vref*Isp; %propulsive efficiency in supersonic cruise
eta0_crs=g/H*Vc*Isp; %propulsive efficiency in subsonic cruise

SFC_ref=SFC;  %[kg/(daN*h)] statistical value {0.2435 PRIMA}

SFC_crs=SFC_ref*eta0_crs/eta0_ref; %[kg/(daN*h)]

end

