function [SFC_crs_MA,V_crs_MA] = SFCscaleMA(fl5,fl6,flMA1,flMA2,ISP,SFC,Mach_utente,C_HyLH2)
%Estimate the SFC in cruise phase through a scale factor (propulsive
%efficiency ratio) related to SFC value for statistical analysis related to main phase of the mission (supersonic
%cruise)
%ATTENTION: this function is related to mission profile WITH MISSED
%APPROACH
%ASSUMPTION: cruise is been done at costant Mach number and variable altitude
%PARAMETERS DESCRIPTION:
%   H: calorific power per unit of mass
%   Isp: specific impulse 
%   M: Mach number
%   q: vector of altitude value
%   Vm: summary of velocity value
%   cont: counter
%   h: current altitude (in the loop)
%   eta0_supercruise: propulsive efficiency in supersonic cruise
%   eta0_subcruise: propulsive efficiency in subsonic cruise
%   SFCsupercruise: specific fuel consumption from statistical value
%   related to superosnic cruise
%   SFCsubcruise:  specific fuel consumption estimeted for the specific
%   cruise phase
%   Vc: cruise velocity
%% CALORIFIC POWER PER UNIT OF MASS 
HLH2=130*1e6;       %[J/kg]
Hkerosene=44.6*1e6; %[J/kg]

if C_HyLH2==1 %hydrocarbon aircraft
    H=Hkerosene;
end

if C_HyLH2==2 %lh2 aircraft
    H=HLH2;
end

%% SPECIFIC IMPULSE
Isp=ISP;  %[s] statistical value

%% MIssed approach cruise

disp(' ')
disp('Insert a value of Mach number  to calculate the velocity')
M=input('');
if flMA1<=flMA2
    h_v=flMA1:1:flMA2;
else
    h_v=flMA1:-1:flMA2;
end
Vm=0;
contV=0;

for i=1:length(h_v)
    
h=h_v(i);
[V] = Speed(h,M);%[m/s]
Vm=Vm+[V];
contV=contV+1;

end

V_crs_MA=Vm/contV;

%% SPEED REFERENCE:PROJECT REQUIREMENTS (IN THIS CASE:SUPERSONIC CRUISE)

Mref=Mach_utente;
h_v=fl5:1:fl6;
Vm=0;
contV=0;

for i=1:length(h_v)
    
h=h_v(i);
M=Mref;
[V] = Speed(h,M);%[m/s]
Vm=Vm+[V];
contV=contV+1;

end

Vref=Vm/contV;

%%
%gravity acceleration [m/s2]
g=9.81; 

eta0_ref=g/H*Vref*Isp; %propulsive efficiency in supersonic cruise
eta0_crs=g/H*V_crs_MA*Isp; %propulsive efficiency in subsonic cruise

SFC_ref=SFC;  %[kg/(daN*h)] statistical value {0.2435 PRIMA}

SFC_crs_MA=SFC_ref*eta0_crs/eta0_ref; %[kg/(daN*h)]


end

