function [V] = Speed(h,M)
%DESCRIPTION: This function estimates the velocity of phases in function of Mach number
%and velocity of sound

T0=288;        %[K] sea level temperature
Th=-6.5/1000;  %gradient of temperature in tropophere[°C/m]

%Temperature estimation
if h<11000     %[m] troposphere
    T=T0+Th*h; %[K]
end

if h >= 11000 %[m] %stratosphere
    T=-56.5+273; %[K]
end

cc=4184;         %constant convertion
a=0.228*cc;      %[J/kg*K]
a1=0.159*cc; %[J/kg*K]
b=3.60*10e-5*cc; %[J/kg*K^2]

%   Specific heating in function of temperature
Cp=a+b*T;  %[J/kg*K]
Cv=a1+b*T; %[J/kg*K]

gamma=Cp/Cv;
R=Cp-Cv; %[J/kg*K]

%Velocity of sound
a=sqrt(gamma*R*T); %[m/s]

%Velocity of phase
V=M*a; %[m/s]
end

