function [MTOW,NT,WS,C_HyLH2,ISP,SFC,Mach_utente,payload_utente,pax_utente] = StatisticalAnalysis()

% DESCRIPTION: INTERPOLATION OF DATABASE VALUES (HYDROCARBON AND LH2
% AIRCRAFTS)

%OUTPUT: PROJECT REQUIREMENTS (PAYLOAD, MACH AND RANGE)
%        STATISTICAL VALUES (MTOW,THRUST,WING SURFACE, SFC, SPECIFIC
%        IMPULSE,PROPELLANT MASS AND FRACTION)
%
%        MTOW (maximum take off weigth)--> Fuel Weight
%        NT (net thrust)-->Aerodynamics
%        WS (wing surface)-->Aerodynamics
%        C_HyLH2(choice)--> Fuel Weight
%        ISP,SFC,Mach_utente-->Fuel Weight
%        Payload_utente -->WS_RequirementVerification
%        Mach_utente --> Fuel weigth
%        pax_uetente (#passeggeri)-->Tank_Layer_Sizing.m
%% IMPORT DATA FROM DATABASE

S_h=importfile1('Database_correct.xlsx','Supersonic_hydrocarbon', [2, 15]);
LH2_c=importfile1('Database_correct.xlsx','LH2_concept',[2, 8]);

%% USER INPUT 

disp(' ')
disp('           PROJECT REQUIREMENTS               ')
disp('Enter values of Mach,Passengers and Range:')
pax_utente=input('Passengers: ');
Mach_utente=input('Mach: ');
Range_utente=input('Range [km]: ');

Cwp=80; %Coeff. weight pax [kg]
Cwl=35; %coeff. weight luggage [kg]

payload_utente=pax_utente*(Cwp+Cwl); %[kg]

disp(['Estimated Payload : ' , num2str(payload_utente),' kg'])

%% Creation of statistical graphic -Supersonic Hydrocarbon: Import data

lab=table2array(S_h(:,1)); 
S_h_m=table2array(S_h(:,2:end)); %convertion table to matrix

MTOW_h=S_h_m(:,2)*1000; %Z conversion from tons to kg [kg]
Payload_h=S_h_m(:,1); %X [kg]
Mach_h=S_h_m(:,7); %Y []

MTOW_hy=zeros(3,1);
%% Creation of statistical graphic -Supersonic Hydrocarbon: MTOW-PAYLOAD 

disp('--------------------------------------------------------------------')
f=fit(Payload_h,MTOW_h,'poly1');
figure (11)
plot(f,Payload_h,MTOW_h)
text(Payload_h,MTOW_h,lab(:,1))
grid minor
xlabel('Payload [kg]')
ylabel('MTOW [kg]')
title('Supersonic Hydrocarbon Aicraft')
legend('aicraft',['fitted curve: f(x)=',num2str(f.p1),'*x+',num2str(f.p2)])

%linear expression for fit: f(x)=p1*x+p2;
MTOW=(f.p1*payload_utente+f.p2)/1000; % [tons]
MTOW_hy(1,1)=MTOW;
disp(['SUPERSONIC HYDROCARBON AIRCFRAFT || [MTOW-Payload] --> MTOW= ', num2str(MTOW),' [tons]'])

%% FIGURE 17: ALL CURVES MTOW-PAYLOAD

figure (17)
plot(f,'r-',Payload_h,MTOW_h,'b*')
text(Payload_h,MTOW_h,lab(:,1))
grid minor
xlabel('Payload [kg]')
ylabel('MTOW [kg]')
legend ('off')

%% Creation of statistical graphic -Supersonic Hydrocarbon:  MTOW-MACH

f=fit(Mach_h,MTOW_h,'poly1');
figure (12)
plot(f,Mach_h,MTOW_h)
text(Mach_h,MTOW_h,lab(:,1))
grid minor
xlabel('Mach ')
ylabel('MTOW [kg]')
title('Supersonic Hydrocarbon Aicraft')
legend('aicraft',['fitted curve: f(x)=',num2str(f.p1),'*x+',num2str(f.p2)])

%linear expression for fit: f(x)=p1*x+p2;
MTOW=(f.p1*Mach_utente+f.p2)/1000; % [tons]
MTOW_hy(2,1)=MTOW;
disp(['SUPERSONIC HYDROCARBON AIRCFRAFT || [MTOW-Mach] --> MTOW= ', num2str(MTOW),' [tons]'])

%% FIGURE 18: ALL CURVES MTOW-MACH

figure (18)
plot(f,'r-',Mach_h,MTOW_h,'b*')
text(Mach_h,MTOW_h,lab(:,1))
grid minor
xlabel('Mach')
ylabel('MTOW [kg]')
legend ('off')

%%  Creation of statistical graphic -Supersonic Hydrocarbon: MTOW-MACH-PAYLOAD 

f=fit([Payload_h,Mach_h],MTOW_h,'poly11');
figure (13)
plot(f,[Payload_h, Mach_h],MTOW_h)
text(Payload_h,Mach_h,MTOW_h,lab(:,1))
grid minor
xlabel('Payload [kg] ')
ylabel('Mach')
zlabel('MTOW [kg]')
title('Supersonic Hydrocarbon Aicraft')

%linear expression for fit: f(x)=p00 + p10*x + p01*y;
MTOW=(f.p00+f.p10*payload_utente+f.p01*Mach_utente)/1000; % [tons]
MTOW_hy(3,1)=MTOW;
disp(['SUPERSONIC HYDROCARBON AIRCFRAFT || [MTOW-Mach-Payload] --> MTOW= ', num2str(MTOW),' [tons]'])

%% Creation of statistical graphic-LH2 concept: Import data 

MTOW_choice=zeros(3,1);

lab=table2array(LH2_c(:,1));
LH2_c_m=table2array(LH2_c(:,2:end)); %convertion table to matrix

MTOW_lh2=LH2_c_m(:,2)*1000; %Z conversion from tons to kg [kg]
Payload_lh2=LH2_c_m(:,1); %X
Mach_lh2=LH2_c_m(:,7); %Y
Range=LH2_c_m(:,10); % [km]

%% Creation of statistical graphic-LH2 concept: MTOW/RANGE-PAYLOAD/RANGE [I DEGREE] 

disp('--------------------------------------------------------------------')
f=fit(Payload_lh2./Range,MTOW_lh2./Range,'poly1');
figure (14)
plot(f,Payload_lh2./Range,MTOW_lh2./Range)
text(Payload_lh2./Range,MTOW_lh2./Range,lab(:,1))
grid on
xlabel('Payload [kg]/Range [km]')
ylabel('MTOW [kg]/Range [km]')
title('LH_2 concept-I degree')
legend('aicraft',['fitted curve: f(x)=', num2str(f.p1),'*x+', num2str(f.p2)]) 

%linear expression for fit: f(x) = p1*x + p2;
MTOW=Range_utente*(f.p1*(payload_utente/Range_utente)+f.p2)/1000; % [tons]

disp(['LH2 CONCEPT AIRCFRAFT || [MTOW/Range-Payload/Range]-I degree --> MTOW= ', num2str(MTOW),' [tons]'])
MTOW_choice(1,1)=MTOW;

%% FIGURE 17: ALL CURVES MTOW-PAYLOAD

f=fit(Payload_lh2,MTOW_lh2,'poly1');
figure (17)
hold on
plot(f,'k-',Payload_lh2,MTOW_lh2,'g*')
text(Payload_lh2,MTOW_lh2,lab(:,1))
xlabel('Payload [kg]')
ylabel('MTOW [kg]')
legend('data: supersonic aircraft','fitted curve:supersonic aircraft','data:LH2 aircfraft','fitted curve: LH2 aircraft')

%% Creation of statistical graphic-LH2 concept: MTOW-MACH [I DEGREE] 

f=fit(Mach_lh2,MTOW_lh2,'poly1');
figure (15)
plot(f,Mach_lh2,MTOW_lh2)
text(Mach_lh2,MTOW_lh2,lab(:,1))
grid minor
xlabel('Mach')
ylabel('MTOW [kg]')
title('LH_2 concept')
legend('aicraft',['fitted curve: f(x)=',num2str(f.p1),'*x+', num2str(f.p2)])


%linear expression for fit: f(x)=p1*x+p2;
MTOW=(f.p1*Mach_utente+f.p2)/1000; % [tons]

disp(['LH2 CONCEPT AIRCFRAFT || [MTOW-Mach] --> MTOW= ', num2str(MTOW),' [tons]'])
MTOW_choice(2,1)=MTOW;


%% FIGURE 18: ALL CURVES MTOW-MACH

f=fit(Mach_lh2,MTOW_lh2,'poly1');
figure (18)
hold on 
plot(f,'k-',Mach_lh2,MTOW_lh2,'g*')
text(Mach_lh2,MTOW_lh2,lab(:,1))
%grid minor
xlabel('Mach')
ylabel('MTOW [kg]')
legend('data:supersonic aircraft','fitted curve:supersonic aircraft','data:LH2 aircraft','fitted curve:LH2 aircraft')


%% Creation of statistical graphic:MTOW/RANGE-MACH/RANGE-PAYLOAD/RANGE - LH2 concept

f=fit([Payload_lh2./Range,Mach_lh2./Range], MTOW_lh2./Range,'poly11');
figure (16)
plot(f,[Payload_lh2./Range,Mach_lh2./Range],MTOW_lh2./Range)
text(Payload_lh2./Range,Mach_lh2./Range,MTOW_lh2./Range,lab(:,1))
grid minor
xlabel('Payload [kg]/Range [km]')
ylabel('Mach/Range [km]')
zlabel('MTOW [kg] /Range [km]')
title('LH_2 concept')


%linear expression for fit: f(x)=p00 + p10*x + p01*y;
MTOW=Range_utente*(f.p00+f.p10*payload_utente/Range_utente+f.p01*Mach_utente/Range_utente)/1000; % [tons]

disp(['LH2 CONCEPT AIRCFRAFT || [MTOW/Range-Mach/Range-Payload/Range] --> MTOW= ', num2str(MTOW),' [tons]'])
MTOW_choice(3,1)=MTOW;%[tons]

%% CHOICE: HYDROCARBON OR LH2 AIRCRAFT

disp(' ')
disp('Do you want develop a hydrocarbon or LH2 aircraft?')
disp('1.Hydrocarbon')
disp('2.LH2')
C_HyLH2=input('');

%% HYDROCARBON AIRCRAFT DEVELOPEMENT
if C_HyLH2==1
    disp(' ')
    disp('1. [MTOW-Payload]')
    
    f=fit(Mach_h,MTOW_h,'poly1');
    Mach_f_1=(MTOW_hy(1,1)*1000-f.p2)/f.p1;
    Payload_f_1=payload_utente; %[kg]
    MTOW_f_1=MTOW_hy(1,1);      %[tons]
    Range_f_1=Range_utente;     %[Km]
    
    disp(['Mach:',num2str(Mach_f_1)])
    disp(['Payload:',num2str(Payload_f_1),' kg '])
    disp(['Passengers:',num2str(Payload_f_1/(Cwp+Cwl)),' kg '])
    disp(['MTOW:',num2str(MTOW_f_1),'tons'])
    disp(['Range:',num2str(Range_f_1), 'km '])
    disp('-----------------------------------------------------------------------------')
    
    disp(' ')
    disp('2. [MTOW-Mach]')
    f=fit(Payload_h,MTOW_h,'poly1');
    Mach_f_2=Mach_utente;
    Payload_f_2=(MTOW_hy(2,1)*1000-f.p2)/f.p1; %[kg]
    MTOW_f_2=MTOW_hy(2,1);  %[tons]
    Range_f_2=Range_utente; %[Km]
    
    disp(['Mach:',num2str(Mach_f_2)])
    disp(['Payload:',num2str(Payload_f_2),' kg '])
    disp(['Passengers:',num2str(Payload_f_2/(Cwp+Cwl)),' kg '])
    disp(['MTOW:',num2str(MTOW_f_2),'tons'])
    disp(['Range:',num2str(Range_f_2), 'Km '])
    disp('-----------------------------------------------------------------------------')
    
    disp(' ')
    disp('3. [MTOW-Mach-Payload]')
    Mach_f_3=Mach_utente;
    Payload_f_3=payload_utente; %[kg]
    MTOW_f_3=MTOW_hy(3,1);  %[tons]
    Range_f_3=Range_utente; %[Km]
    
    disp(['Mach:',num2str(Mach_f_3)])
    disp(['Payload:',num2str(Payload_f_3),' kg '])
    disp(['Passengers:',num2str(Payload_f_3/(Cwp+Cwl)),' kg '])
    disp(['MTOW:',num2str(MTOW_f_3),'tons'])
    disp(['Range:',num2str(Range_f_3), 'Km '])
    disp('-----------------------------------------------------------------------------')
    
    disp(' ')
    disp('4. Estimated MTOW such as medium')
    disp('Choose a weight for the main parameters to determite MTOW. Insert a value from 0 to 100:')
    wM=input('Weight of MACH:');
    wP=input('Weight of Payload:');
    
    wMP=50;
    
    num=wM*MTOW_hy(2,1)+wP*MTOW_hy(1,1)+wMP*MTOW_hy(3,1);
    den=wM+wP+wMP;
    
    MTOW_f_4=num/den;
    Mach_f_4=Mach_utente;
    Payload_f_4=payload_utente; %[kg]
    Range_f_4=Range_utente; %[Km]
    
    disp(['Mach:',num2str(Mach_f_4)])
    disp(['Payload:',num2str(Payload_f_4),' kg '])
    disp(['Passengers:',num2str(Payload_f_4/(Cwp+Cwl)),' kg '])
    disp(['MTOW estimated: ', num2str(MTOW_f_4),' tons'])
    disp(['Range:',num2str(Range_f_4), 'Km '])
    
    disp('-----------------------------------------------------------------------------')
    
    disp('Enter choice from 1 to 4 to estimate MTOW: ')
    c_MTOW=input(' ');

    if c_MTOW==1 %[MTOW-Payload]
        Mach=Mach_f_1;
        Payload=Payload_f_1; %[kg]
        MTOW=MTOW_f_1; %[tons]
        Range=Range_f_1; %[Km]
    end

    if c_MTOW==2 %[MTOW-Mach]
        Mach=Mach_f_2;
        Payload=Payload_f_2; %[kg]
        MTOW=MTOW_f_2; %[tons]
        Range=Range_f_2; %[Km]
    end

    if c_MTOW==3 %[MTOW/Range-Mach/Range-Payload/Range]
        Mach=Mach_f_3;
        Payload=Payload_f_3; %[kg]
        MTOW=MTOW_f_3; %[tons]
        Range=Range_f_3; %[Km]
    end

    if c_MTOW==4 %Estimated MTOW such as medium
        Mach=Mach_f_4;
        Payload=Payload_f_4; %[kg]
        MTOW=MTOW_f_4; %[tons]
        Range=Range_f_4; %[Km]
    end

%% ESTIMATING OTHERS PARAMETERS 
lab=table2array(S_h(:,1));

% MTOW-NET THRUST

f=fit(MTOW_h(1:(end-1),1), S_h_m(1:(end-1),3),'poly1');
figure (19)
plot(f,MTOW_h,S_h_m(:,3))
text(MTOW_h,S_h_m(:,3),lab(:,1))
hold on
legend('off')
grid minor
ylabel('Net thrust [kN]')
xlabel('MTOW[kg]')

%linear expression for fit: f(x)=p1*x+p2;
NT=f.p1*MTOW*1000+f.p2;
hold on
plot(MTOW*1000,NT, '^k','Linewidth',2)
text(MTOW*1000,NT,'  NEW CONCEPT')
plot(S_h_m(12,2)*1000,S_h_m(12,3),'*k','Linewidth',2)
text(S_h_m(12,2)*1000,S_h_m(12,3),'Boom Overture')
legend('aircraft',['Fitted curve: f(x)=',num2str(f.p1),'*x + ',num2str(f.p2)])

%MTOW- wing surface[m^2]

f=fit(MTOW_h,S_h_m(:,4),'poly1');
figure (110)
plot(f,MTOW_h,S_h_m(:,4))
text(MTOW_h,S_h_m(:,4),lab(:,1))
hold on
legend('off')
grid minor
ylabel('Wing surface [m^2]')
xlabel('MTOW[kg]')

%linear expression for fit: f(x)=p1*x+p2;
WS=f.p1*MTOW*1000+f.p2;
hold on
plot(MTOW*1000,WS, '^k','LineWidth',2)
text(MTOW*1000,WS,'  NEW CONCEPT')
plot(S_h_m(12,2)*1000,S_h_m(12,4),'*k','Linewidth',2)
text(S_h_m(12,2)*1000,S_h_m(12,4),'Boom Overture')
legend(['Fitted curve: f(x)=',num2str(f.p1),'*x + ',num2str(f.p2)])
legend('aircraft',['Fitted curve: f(x)=',num2str(f.p1),'*x + ',num2str(f.p2)])

%MTOW-SFC [kg/daN/h]

f=fit(MTOW_h,S_h_m(:,5),'poly1');
figure (111)
plot(f,MTOW_h,S_h_m(:,5))
text(MTOW_h,S_h_m(:,5),lab(:,1))
legend('off')
grid minor
ylabel('SFC [kg/daN/h]')
xlabel('MTOW[kg]')

%linear expression for fit: f(x)=p1*x+p2;
SFC=f.p1*MTOW*1000+f.p2;
hold on
plot(MTOW*1000,SFC, '^k','Linewidth',2)
text(MTOW*1000,SFC,'  NEW CONCEPT')
plot(S_h_m(12,2)*1000,S_h_m(12,5),'*k','Linewidth',2)
text(S_h_m(12,2)*1000,S_h_m(12,5),'Boom Overture')
legend('aircraft',['Fitted curve: f(x)=',num2str(f.p1),'*x + ',num2str(f.p2)])

%MTOW-Isp [s] 

f=fit(MTOW_h,S_h_m(:,6),'poly1');
figure (112)
plot(f,MTOW_h,S_h_m(:,6))
text(MTOW_h,S_h_m(:,6),lab(:,1))
legend('off')
grid minor
ylabel('I_s_p [s]')
xlabel('MTOW[kg]')

%linear expression for fit: f(x)=p1*x+p2;
ISP=f.p1*MTOW*1000+f.p2;
hold on
plot(MTOW*1000,ISP, '^k','Linewidth',2)
text(MTOW*1000,ISP,'  NEW CONCEPT')
plot(S_h_m(12,2)*1000,S_h_m(12,6),'*k','Linewidth',2)
text(S_h_m(12,2)*1000,S_h_m(12,6),'Boom Overture')
legend('aircraft',['Fitted curve: f(x)=',num2str(f.p1),'*x + ',num2str(f.p2)])

%MTOW-Propellant mass [kg] 

f=fit(MTOW_h,S_h_m(:,8),'poly1');
figure (113)
plot(f,MTOW_h,S_h_m(:,8))
text(MTOW_h,S_h_m(:,8),lab(:,1))
legend('off')
grid minor
ylabel('Propellant mass [kg]')
xlabel('MTOW[kg]')

%linear expression for fit: f(x)=p1*x+p2;
PM=f.p1*MTOW*1000+f.p2;
hold on
plot(MTOW*1000,PM, '^k','Linewidth',2)
text(MTOW*1000,PM,'  NEW CONCEPT')
plot(S_h_m(12,2)*1000,S_h_m(12,8),'*k','Linewidth',2)
text(S_h_m(12,2)*1000,S_h_m(12,8),'Boom Overture')
legend('aircraft',['Fitted curve: f(x)=',num2str(f.p1),'*x + ',num2str(f.p2)])

%MTOW- Propellant mass fraction

f=fit(MTOW_h,S_h_m(:,9),'poly1');
figure (114)
plot(f,MTOW_h,S_h_m(:,9))
text(MTOW_h,S_h_m(:,9),lab(:,1))
legend('off')

grid minor
ylabel('Propellant mass fraction [%]')
xlabel('MTOW[kg]')

%linear expression for fit: f(x)=p1*x+p2;
PMF=f.p1*MTOW*1000+f.p2;
hold on
plot(MTOW*1000,PMF, '^k','Linewidth',2)
text(MTOW*1000,PMF,'  NEW CONCEPT')
plot(S_h_m(12,2)*1000,S_h_m(12,9),'*k','Linewidth',2)
text(S_h_m(12,2)*1000,S_h_m(12,9),'Boom Overture')
legend('aircraft',['Fitted curve: f(x)=',num2str(f.p1),'*x + ',num2str(f.p2)])

disp('---------------------------------------------------------------')
disp('Statistical estimation of parameters of first point of project:')
disp(['MTOW                      --> ',num2str(MTOW),' tons'])
disp(['NET THRUST                --> ',num2str(NT),' kN'])
disp(['WING SURFACE              --> ',num2str(WS),' m^2'])
disp(['SFC                       --> ',num2str(SFC),' kg/daN/h'])
disp(['Isp                       --> ',num2str(ISP),' s'])
disp(['PROPELLANT MASS           --> ',num2str(PM),' kg '])
disp(['PROPELLANT MASS FRACTION  --> ',num2str(PMF),' % '])

%% GRAPH: SFC-NET THRUST

f=fit( S_h_m(1:(end-1),3),S_h_m(1:(end-1),5),'poly1');
figure (115)
plot(f, S_h_m(1:(end-1),3),S_h_m(1:(end-1),5))
%text( S_h_m(1:(end-1),3),S_h_m(1:(end-1),5),lab(:,1))

legend('off')
grid minor
ylabel('SFC [kg/daN/h]')
xlabel('Net thrust [kN]')
hold on
plot(NT,SFC, '^k','Linewidth',2)
text(NT,SFC,'  NEW CONCEPT')
plot(S_h_m(12,3),S_h_m(12,5),'*k','Linewidth',2)
text(S_h_m(12,3),S_h_m(12,5),'Boom Overture')
  
end
%% LH2 AIRCRAFT DEVELOPMENT
 
if C_HyLH2==2  
%% 
disp(' ')
disp('1. [MTOW/Range-Payload/Range]-I degree')

f=fit(Mach_lh2,MTOW_lh2,'poly1');
Mach_f_1=(MTOW_choice(1,1)*1000-f.p2)/f.p1;
Payload_f_1=payload_utente;                 %[kg]
MTOW_f_1=MTOW_choice(1,1);                  %[tons]
Range_f_1=Range_utente;                     %[Km]

disp(['Mach:',num2str(Mach_f_1)])
disp(['Payload:',num2str(Payload_f_1),' kg '])
disp(['Passengers:',num2str(Payload_f_1/(Cwp+Cwl)),' kg '])
disp(['MTOW:',num2str(MTOW_f_1),'tons'])
disp(['Range:',num2str(Range_f_1), 'km '])
disp('-----------------------------------------------------------------------------')

disp(' ')
disp('2. [MTOW-Mach]')
disp('Insert a value of range (because the fitted curve is normalized for this parameter) :')
r=input('');

f=fit(Payload_lh2./Range,MTOW_lh2./Range,'poly1');
Mach_f_2=Mach_utente;
Payload_f_2=((MTOW_choice(2,1)/r*1000-f.p2)/f.p1)*r; %[kg]
MTOW_f_2=MTOW_choice(2,1);  %[tons]

disp(['Mach:',num2str(Mach_f_2)])
disp(['Payload:',num2str(Payload_f_2),' kg '])
disp(['Passengers:',num2str(Payload_f_2/(Cwp+Cwl)),' kg '])
disp(['MTOW:',num2str(MTOW_f_2),'tons'])
disp('-----------------------------------------------------------------------------')

disp(' ')
disp('3. [MTOW/Range-Mach/Range-Payload/Range]')
Mach_f_3=Mach_utente;
Payload_f_3=payload_utente; %[kg]
MTOW_f_3=MTOW_choice(3,1);  %[tons]
Range_f_3=Range_utente; %[Km]

disp(['Mach:',num2str(Mach_f_3)])
disp(['Payload:',num2str(Payload_f_3),' kg '])
disp(['Passengers:',num2str(Payload_f_3/(Cwp+Cwl)),' kg '])
disp(['MTOW:',num2str(MTOW_f_3),'tons'])
disp(['Range:',num2str(Range_f_3), 'Km '])
disp('-----------------------------------------------------------------------------')

disp(' ')
disp('4. Estimated MTOW such as medium')
disp('Choose a weight for the main parameters to determite MTOW. Insert a value from 0 to 100:')
wM=input('Weight of MACH:');
wP=input('Weight of Payload:');
 
wMP=50;

num=wM*MTOW_choice(2,1)+wP*MTOW_choice(1,1)+wMP*MTOW_choice(3,1);
den=wM+wP+wMP;

MTOW_f_4=num/den;
Mach_f_4=Mach_utente;
Payload_f_4=payload_utente; %[kg]
Range_f_4=Range_utente; %[Km]

disp(['MTOW estimated: ', num2str(MTOW_f_4),' tons'])

disp('-----------------------------------------------------------------------------')

disp('Enter choice from 1 to 4 to estimate MTOW: ')
c_MTOW=input(' ');

if c_MTOW==1 %[MTOW/Range-Payload/Range]-I degree
    Mach=Mach_f_1;
    Payload=Payload_f_1; %[kg]
    MTOW=MTOW_f_1; %[tons]
    Range=Range_f_1; %[Km]
end

if c_MTOW==2 %[MTOW-Mach]
    Mach=Mach_f_2;
    Payload=Payload_f_2; %[kg]
    MTOW=MTOW_f_2; %[tons]
    Range=r; %[Km]
end

if c_MTOW==3 %[MTOW/Range-Mach/Range-Payload/Range]
    Mach=Mach_f_3;
    Payload=Payload_f_3; %[kg]
    MTOW=MTOW_f_3; %[tons]
    Range=Range_f_3; %[Km]
end

if c_MTOW==4 %Estimated MTOW such as medium
    Mach=Mach_f_4;
    Payload=Payload_f_4; %[kg]
    MTOW=MTOW_f_4; %[tons]
    Range=Range_f_4; %[Km]
end

%%  ESTIMATION OTHERS PARAMETERS 

%MTOW-NET THRUST

f=fit(MTOW_lh2, LH2_c_m(:,3),'poly1');
figure (19)
plot(f,MTOW_lh2,LH2_c_m(:,3))
text(MTOW_lh2,LH2_c_m(:,3),lab(:,1))
legend('off')
grid minor
ylabel('Net thrust [kN]')
xlabel('MTOW[kg]')

%linear expression for fit: f(x)=p1*x+p2;
NT=f.p1*MTOW*1000+f.p2;
hold on
plot(MTOW*1000,NT, '^k','Linewidth',2)
text(MTOW*1000,NT,'  NEW CONCEPT')
plot(S_h_m(12,2)*1000,S_h_m(12,3),'*k','Linewidth',2)
text(S_h_m(12,2)*1000,S_h_m(12,3),'Boom Overture')
legend('aircraft',['Fitted curve: f(x)=',num2str(f.p1),'*x + ',num2str(f.p2)])


%MTOW- wing surface[m^2]

f=fit(MTOW_lh2,LH2_c_m(:,4),'poly1');
figure (110)
plot(f,MTOW_lh2,LH2_c_m(:,3))
text(MTOW_lh2,LH2_c_m(:,3),lab(:,1))
legend('off')
grid minor
ylabel('Wing surface [m^2]')
xlabel('MTOW[kg]')

%linear expression for fit: f(x)=p1*x+p2;
WS=f.p1*MTOW*1000+f.p2;
hold on
plot(MTOW*1000,WS, '^k','Linewidth',2)
text(MTOW*1000,WS,'  NEW CONCEPT')
plot(S_h_m(12,2)*1000,S_h_m(12,4),'*k','Linewidth',2)
text(S_h_m(12,2)*1000,S_h_m(12,4),'Boom Overture')
legend(['Fitted curve: f(x)=',num2str(f.p1),'*x + ',num2str(f.p2)])
legend('aircraft',['Fitted curve: f(x)=',num2str(f.p1),'*x + ',num2str(f.p2)])

%MTOW-SFC [kg/daN/h]

f=fit(MTOW_lh2,LH2_c_m(:,5),'poly1');
figure (111)
plot(f,MTOW_lh2,LH2_c_m(:,5))
text(MTOW_lh2,LH2_c_m(:,5),lab(:,1))
legend('off')
grid minor
ylabel('SFC [kg/daN/h]')
xlabel('MTOW[kg]')

%linear expression for fit: f(x)=p1*x+p2;
SFC=f.p1*MTOW*1000+f.p2;
hold on
plot(MTOW*1000,SFC, '^k','Linewidth',2)
text(MTOW*1000,SFC,'  NEW CONCEPT')
plot(S_h_m(12,2)*1000,S_h_m(12,5),'*k','Linewidth',2)
text(S_h_m(12,2)*1000,S_h_m(12,5),'Boom Overture')
legend('aircraft',['Fitted curve: f(x)=',num2str(f.p1),'*x + ',num2str(f.p2)])

%MTOW-Isp [s] 

f=fit(MTOW_lh2,LH2_c_m(:,6),'poly1');
figure (112)
plot(f,MTOW_lh2,LH2_c_m(:,6))
text(MTOW_lh2,LH2_c_m(:,6),lab(:,1))
legend('off')
grid minor
ylabel('I_s_p [s]')
xlabel('MTOW[kg]')

%linear expression for fit: f(x)=p1*x+p2;
ISP=f.p1*MTOW*1000+f.p2;
hold on
plot(MTOW*1000,ISP, '^k','Linewidth',2)
text(MTOW*1000,ISP,'  NEW CONCEPT')
plot(S_h_m(12,2)*1000,S_h_m(12,6),'*k','Linewidth',2)
text(S_h_m(12,2)*1000,S_h_m(12,6),'Boom Overture')
legend('aircraft',['Fitted curve: f(x)=',num2str(f.p1),'*x + ',num2str(f.p2)])

%MTOW-Propellant mass [kg] 

f=fit(MTOW_lh2,LH2_c_m(:,8),'poly1');
figure (113)
plot(f,MTOW_lh2,LH2_c_m(:,8))
text(MTOW_lh2,LH2_c_m(:,8),lab(:,1))
legend('off')
grid minor
ylabel('Propellant mass [kg]')
xlabel('MTOW[kg]')

%linear expression for fit: f(x)=p1*x+p2;
PM=f.p1*MTOW*1000+f.p2;
hold on
plot(MTOW*1000,PM, '^k','Linewidth',2)
text(MTOW*1000,PM,'  NEW CONCEPT')
plot(S_h_m(12,2)*1000,S_h_m(12,8),'*k','Linewidth',2)
text(S_h_m(12,2)*1000,S_h_m(12,8),'Boom Overture')
legend('aircraft',['Fitted curve: f(x)=',num2str(f.p1),'*x + ',num2str(f.p2)])

%MTOW- Propellant mass fraction

f=fit(MTOW_lh2,LH2_c_m(:,9),'poly1');
figure (114)
plot(f,MTOW_lh2,LH2_c_m(:,9))
text(MTOW_lh2,LH2_c_m(:,9),lab(:,1))
legend('off')

% %SOLUZIONE ANALITICA ESPONENZIALE
% hold on
% plot(MTOW_lh2,(log(MTOW_lh2/(5.47*10e4))/0.7042),'-.r')

grid minor
ylabel('Propellant mass fraction [%]')
xlabel('MTOW[kg]')

%linear expression for fit: f(x)=p1*x+p2;
PMF=f.p1*MTOW*1000+f.p2;
hold on
plot(MTOW*1000,PMF, '^k','Linewidth',2)
text(MTOW*1000,PMF,'  NEW CONCEPT')
plot(S_h_m(12,2)*1000,S_h_m(12,9),'*k','Linewidth',2)
text(S_h_m(12,2)*1000,S_h_m(12,9),'Boom Overture')
legend('aircraft',['Fitted curve: f(x)=',num2str(f.p1),'*x + ',num2str(f.p2)])

disp('---------------------------------------------------------------')
disp('Statistical estimation of parameters of first point of project:')
disp(['MTOW                      --> ',num2str(MTOW),' tons'])
disp(['NET THRUST                --> ',num2str(NT),' kN'])
disp(['WING SURFACE              --> ',num2str(WS),' m^2'])
disp(['SFC                       --> ',num2str(SFC),' kg/daN/h'])
disp(['Isp                       --> ',num2str(ISP),' s'])
disp(['PROPELLANT MASS           --> ',num2str(PM),' kg '])
disp(['PROPELLANT MASS FRACTION  --> ',num2str(PMF),' % '])

%% GRAPH: SFC-NET THRUST

f=fit(LH2_c_m(:,3),LH2_c_m(:,5),'poly1');
figure (115)
plot(f,LH2_c_m(:,3),LH2_c_m(:,5))
text(LH2_c_m(:,3),LH2_c_m(:,5),lab(:,1))

legend('off')
grid minor
ylabel('SFC [kg/daN/h]')
xlabel('Net thrust [kN]')
hold on
plot(NT,SFC, '^k','Linewidth',2)
text(NT,SFC,'  NEW CONCEPT')
plot(S_h_m(12,3),S_h_m(12,5),'*k','Linewidth',2)
text(S_h_m(12,3),S_h_m(12,5),'Boom Overture')
legend('aircraft',['Fitted curve: f(x)=',num2str(f.p1),'*x + ',num2str(f.p2)])

end
clc
disp('*******************************************************************')
disp('*******************************************************************')
disp('                      STATISTICAL ANALYSIS                         ')

disp(['Mach:',num2str(Mach)])
disp(['Payload:',num2str(Payload),' kg '])
disp(['Passengers:',num2str(Payload/(Cwp+Cwl)),' kg '])
disp(['Range:',num2str(Range), 'Km '])

disp('---------------------------------------------------------------')
disp('Statistical estimation of parameters of first point of project:')
disp(['MTOW                      --> ',num2str(MTOW),' tons'])
disp(['NET THRUST                --> ',num2str(NT),' kN'])
disp(['WING SURFACE              --> ',num2str(WS),' m^2'])
disp(['SFC                       --> ',num2str(SFC),' kg/daN/h'])
disp(['Isp                       --> ',num2str(ISP),' s'])
disp(['PROPELLANT MASS           --> ',num2str(PM),' kg '])
disp(['PROPELLANT MASS FRACTION  --> ',num2str(PMF),' % '])
end


