function [Sratio, Sref, Scov, Sexp,c_SRM] = SurfaceRatio(b,cr_w,d_ext,WS)
%Three methods to estimate the surface ratio:

%1-Dummy approach: The wing is considered such as a triangle with (b/2-d/2)
%as a base and root chord for height
%Sexp: surface exposed of half wing , one part (or buttom or up)
%Scov: wing surface 'covered' by the fuselage , assuming as a rectangle
%with (d x cr) dimensions
%Sref: Reference surface , the intair surface: two times the exposed plus
%the covered 
% Sratio=Sexposed,total/Sref=(Sref-Scov)/Sref=1-Scov/Sref

%2-Concorde related approach
%Sref is assuming by statistical values relating to Concorde
%S cov is the same rectangle of previous method

%3-Statistical analysis approach
%Sref is assuming by statistical values in output for this case of study
%S cov is the same rectangle of previous method

disp('-------------------------------------------------------------------')
disp('Surface ratio methods:')
disp(' ')

%Dummy approach
Sexp=((b/2-d_ext/2)*cr_w)/2; %[m2]
Scov=d_ext*cr_w; %[m2]

Sref_d=2*Sexp+Scov; %[m2]

Sratio_d=Sexp*2/Sref_d;
disp('1.Dummy approach')
disp(['Sexp/Sref=',num2str(Sratio_d)])
disp(' ')

%Concorde related approach
Sref_c=358; %[m] 
Sratio_c=1-Scov/Sref_c;

disp('2.Concorde related approach')
disp(['Sexp/Sref=',num2str(Sratio_c)])
disp(' ')

%Statistical analysis approach
Sref_s=WS;  %[m]  statistical value:296
Sratio_s=1-Scov/Sref_s;

disp('3.Statistical analysis approach')
disp(['Sexp/Sref=',num2str(Sratio_s)])
disp(' ')

disp('Choose one method to continue:')
disp('1. Dummy')
disp('2. Concorde')
disp('3. Statistical analysis')
c_SRM=input('');

disp('-------------------------------------------------------------------')

if c_SRM==2  %CONCORDE RELATED METHOD
    Sexp=(Sratio_c*Sref_c)/2;
    Sref=Sref_c;
    Sratio=Sratio_c;
end
 
if c_SRM==1  %DUMMY METHOD
    Sexp=Sexp;
    Sref=Sref_d;
    Sratio=Sratio_d;
end

if c_SRM==3  %STATISTCIAL ANALYSIS METHOD
    Sexp=(Sratio_s*Sref_s)/2;
    Sref=Sref_s;
    Sratio=Sratio_s;
end

end

