function [SFC_climb,Vclimb,rclimb,W4W3] = WeightRatio_RangeSpeed(fl4,fl5,SFC,t4,E_sub,E_sup,Msub,Msup)

%This function estimates the weigth ratio in supersonic climb adopting the
%Breguet formulation with RANGE & VELOCITY
%   SFC: specific fuel compsantion
%   percT: percentage of throttle
%   L/D: aerodynamic efficiency 
%   Wi/Wi-1: weigth ratio


%% ASSUMPTION: in supersonic cruise condition the throttle is supposed 80%
percT_cruise=80; %[ % ]
percT_climb=100; %[ % ]
SFC_climb=percT_climb/percT_cruise*SFC; %[kg/(daN*h)]
%disp(['SFC ',num2str(SFCclimb),'kg/daN/h'])
SFCclimb=SFC_climb/(10*3600); %[kg/(N*s)]

%% AERODYNAMIC EFFICIENCY
LDclimb=(E_sub+E_sup)/2;

%% ITERATION
Mi=Msub;
Mf=Msup;
h_v=fl4:1:fl5;
dt=(Mf-Mi)/length(h_v);
M_v=Mi:dt:Mf;
l=min(length(M_v),length(h_v));
cont_WR=0;
W4W3m=0;

for i=1:l
    
    M=M_v(i);
    h=h_v(i);
    
    [V] = Speed(h,M);
    
    rclimb=V*t4*60; %[m]
    
    W4W3=exp(-(rclimb*SFCclimb*9.81)/(V*LDclimb));
    
    W4W3m=W4W3m+W4W3;
    
    cont_WR=cont_WR+1;

end
Vclimb=V;
W4W3=W4W3m/cont_WR;
end

