function DatabasecorrectS1 = importfile1(workbookFile, sheetName, dataLines)
%IMPORTFILE Import data from a spreadsheet
%  DATABASECORRECTS1 = IMPORTFILE(FILE) reads data from the first
%  worksheet in the Microsoft Excel spreadsheet file named FILE.
%  Returns the data as a table.
%
%  DATABASECORRECTS1 = IMPORTFILE(FILE, SHEET) reads from the specified
%  worksheet.
%
%  DATABASECORRECTS1 = IMPORTFILE(FILE, SHEET, DATALINES) reads from the
%  specified worksheet for the specified row interval(s). Specify
%  DATALINES as a positive scalar integer or a N-by-2 array of positive
%  scalar integers for dis-contiguous row intervals.
%
%  Example:
%  DatabasecorrectS1 = importfile("C:\Users\elena\OneDrive\Desktop\Tesi_Magistrale\Preliminary_analysis - Range\Database_correct.xlsx", "LH2_concept", [2, 7]);
%
%  See also READTABLE.
%
% Auto-generated by MATLAB on 01-Nov-2020 09:50:30

%% Input handling

% If no sheet is specified, read first sheet
if nargin == 1 || isempty(sheetName)
    sheetName = 1;
end

% If row start and end points are not specified, define defaults
if nargin <= 2
    dataLines = [2, 7];
end

%% Set up the Import Options and import the data
opts = spreadsheetImportOptions("NumVariables", 11);

% Specify sheet and range
opts.Sheet = sheetName;
opts.DataRange = "A" + dataLines(1, 1) + ":K" + dataLines(1, 2);

% Specify column names and types
opts.VariableNames = ["Name", "Payloadkg", "MTOWtons", "TkN", "Sm2", "sfckgdaNh", "Isps", "Mach", "PropellantMasskg", "PropellantMassFraction", "Rangekm"];
opts.VariableTypes = ["string", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double"];

% Specify variable properties
opts = setvaropts(opts, "Name", "WhitespaceRule", "preserve");
opts = setvaropts(opts, "Name", "EmptyFieldRule", "auto");

% Import the data
DatabasecorrectS1 = readtable(workbookFile, opts, "UseExcel", false);

for idx = 2:size(dataLines, 1)
    opts.DataRange = "A" + dataLines(idx, 1) + ":K" + dataLines(idx, 2);
    tb = readtable(workbookFile, opts, "UseExcel", false);
    DatabasecorrectS1 = [DatabasecorrectS1; tb]; %#ok<AGROW>
end

end